@@ -15,6 +15,20 @@ def 异步简用(func):
     return newfunc
 
 
+def 失败重试(最高次数, 重试间隔=0, 每次失败执行=None):
+    def retry(func):
+        def newfunc(*vs, **kvs):
+            for i in range(1, 最高次数+1):
+                try: return True, func(*vs, **kvs)
+                except Exception as err:
+                    e = err
+                    if i < 最高次数: time.sleep(重试间隔)
+                    if 每次失败执行: 每次失败执行()
+            return False, e
+        return newfunc
+    return retry
+
+
 class 装饰器():
     tool = tool
 
