@@ -37,13 +37,13 @@ class 起点计费系统api():
         入参data = datas
         datas = {"AppKey": self.AppKey, "TimeStamp": math.floor(time.time()), "Data": datas}
         req = f'"{self.aes_ecb_pkcs7(json.dumps(datas))}"'
-        for n in range(20):  # 因为计费系统的服务器太垃圾, 经常会无响应, 所以需要多次重试
+        for n in range(10):  # 因为计费系统的服务器太垃圾, 经常会无响应, 所以需要多次重试
             try:
                 return requests.post(url, headers=self.headers, data=req).json()
             except Exception as err:
                 print(err)
                 e = err
-                if 'Max retries exceeded with url' in str(err): time.sleep(1.5)
+                if 'Max retries exceeded with url' in str(err): time.sleep(1)
                 # 服务器无响应时, request库不断进行重新请求, 于是便会导致连接过多
         if self.请求失败日志路径:
             try:
@@ -55,32 +55,23 @@ class 起点计费系统api():
         raise e
 
     def 获取关键词(self, 审核=True, 启用=True, 搜索引擎='全部'):  # 返回结构: [{}, {}]
-        r = ''
-        for i in range(20):
-            try:
-                审核, 启用, 搜索引擎 = self.审核字典[审核], self.启用字典[启用], self.搜索引擎字典[搜索引擎]
-                req = {"AuditState":审核, "RankType":搜索引擎, "PageSize": 30000, "PageNum": 1, 'IsEnabled':启用}
-                r = self.请求服务器('http://api.235kk.com/api/Words', req)
-                print('\n获取关键词'+r['message'], '  请求状态', r['state'], end='    ')
-                d = r['data']
-                print('总记录', d['TotalNum'], '   当前页', d['CurrentPage'], '   总页数', d['TotalPageCount'], '  ', d['OtherData'])
-                r = d['Items']
-                for x in r: x['kwid'] = x.pop('WordID')
-                return r
-            except:
-                print(str(r)[:500])
-                time.sleep(10)
-        else:
+        allkw = []
+        TotalPageCount = ''
+        for page in range(1, 10000):
+            print(f"\r正在获取关键词 第{page}/{TotalPageCount}页", end='    ')
             审核, 启用, 搜索引擎 = self.审核字典[审核], self.启用字典[启用], self.搜索引擎字典[搜索引擎]
-            req = {"AuditState":审核, "RankType":搜索引擎, "PageSize": 30000, "PageNum": 1, 'IsEnabled':启用}
+            req = {"AuditState":审核, "RankType":搜索引擎, "PageSize":2000, "PageNum":page, 'IsEnabled':启用}
             r = self.请求服务器('http://api.235kk.com/api/Words', req)
-            print('\n获取关键词'+r['message'], '  请求状态', r['state'], end='    ')
-            d = r['data']
-            print('总记录', d['TotalNum'], '   当前页', d['CurrentPage'], '   总页数', d['TotalPageCount'], '  ', d['OtherData'])
-            r = d['Items']
-            for x in r: x['kwid'] = x.pop('WordID')
-            return r
-    
+            message, data, state = [r[x] for x in ('message', 'data', 'state')]
+            TotalNum, Items, CurrentPage, TotalPageCount, OtherData = [data[x] for x in ('TotalNum', 'Items', 'CurrentPage', 'TotalPageCount', 'OtherData')]
+            for x in Items:
+                x['kwid'] = x.pop('WordID')
+                x['最新排名'] = x.pop('RankNum') or 51
+                allkw.append(x)
+            if page >= TotalPageCount:
+                print(f"\n提取关键词完成, 共{len(allkw)}条.")
+                return allkw
+
     def 修改审核状态(self, kws):  # 传入结构: [{'kwid':kwid, '审核':True}, {'kwid':kwid, '审核':True}]
         kws = [dict(WordID=kw['kwid'], AuditState=self.审核字典[kw['审核']]) for kw in kws]
         r = self.请求服务器('http://api.235kk.com/api/WordsInfo', kws)
