@@ -494,21 +494,21 @@ class 善检网api第2版_套餐_百度(善检网api第2版_套餐):
     def 匹配人群标签(self, text, 规则=None):
         text = text.lower()
         规则 = 规则 or {
-            '男性体检': ['男'],
-            '青少年体检': ['少年'],
-            '中老年体检': ['老年'],
-            '女性体检': ['女'],
-            '商务体检': ['商务'],
-            '儿童体检': ['儿童'],
-            '白领体检': ['白领'],
-            '优生优育': ['优生'],
-            '入职体检': ['入职', '招工'],
-            '防癌筛查': ['癌'],
-            '公务员体检': ['公务员'],
-            '父母体检': ['父母'],
-            '婚检孕检': ['婚', '孕', '优生']
+            '入职体检': (['入职', '招工'],[]),
+            '防癌筛查': (['癌'],[]),
+            '公务员体检': (['公务员'],[]),
+            '父母体检': (['父母'],[]),
+            '婚检孕检': (['婚', '孕', '优生'],[])
         }
-        return set(k for k, v in 规则.items() for x in v if x in text)
+        tags, 互斥 = set(), set()
+        for k,vs in 规则.items():
+            if k not in 互斥:
+                ps, chs = vs
+                if [x for x in ps if x in text]:
+                    if not [x for x in chs if x in tags]:
+                        tags.add(k)
+                        for x in chs: 互斥.add(x)
+        return tags
     
     def 提取唯一值(self, 字段名称, data, 非空=False):
         data = set(data)
@@ -613,8 +613,9 @@ class 善检网api第2版_套餐_百度(善检网api第2版_套餐):
                 特色标签s = [self.标签字典['套餐特色标签'][x] for x in set(特色标签s)]
                 特色标签s = [dict(groupKey='package_tag', tagCode=x['标签代号'], tagId=x['标签id']) for x in 特色标签s]
                 if not 特色标签s: raise Exception(f"{标识符} - 特色标签不能为空")
-                人群名称s = [y for x in list(df[年龄字段]) for y in re.split(' +', x)] + list(self.匹配人群标签(套餐名称, 规则=套餐人群标签匹配规则))
-                人群名称s = list(set(人群名称s))
+                
+                人群名称s = list(self.匹配人群标签(套餐名称+str(list(df[年龄字段])), 规则=套餐人群标签匹配规则))
+
                 人群标签s = [self.标签字典['套餐类型'][x] for x in set(人群名称s)]
                 if not 人群标签s: raise Exception(f"{标识符} - 类型标签不能为空")
                 套餐名称标签类型 = 人群标签s[0]['标签名称']
