@@ -201,6 +201,37 @@ class 供应链api():
         self.二级单项字典 = item = {}
         for x in data: item[x['单项组id']] = item[x['单项组名称']] = x
         return data
+
+    def 获取全部机构id(self, 去除test=True):
+        if 去除test:
+            return list(set(x['机构id'] for x in self.机构字典.values() if (('test' not in x['机构名称']) and ('测试' not in x['机构名称']))))
+        return list(set(x['机构id'] for x in self.机构字典.values()))
+
+    def 新增假日策略(self, 机构id, 假期名称, 开始日期, 结束日期):
+        data = dict(orgId=机构id, holidayName=假期名称, startTime=开始日期, endTime=结束日期,
+        sync=0)
+        try:
+            r = self.post("org/holiday-schedule", data=data)
+            msg = r.get('message') or str(r)
+        except Exception as err:
+            msg = str(err)
+        if msg in ['OK', '成功', 'SUCCESS']:
+            return True, msg
+        return False, msg
+
+    def 全服新增假日策略(self, 假期名称, 开始日期, 结束日期):
+        rs = {}
+        oids = self.获取全部机构id()
+        total = len(oids)
+        for i, oid in enumerate(oids):
+            print(f"\r{i}\{total}", end='   ')
+            r = self.新增假日策略(机构id=oid, 假期名称=假期名称, 开始日期=开始日期, 结束日期=结束日期)
+            if r[0] is True:
+                rs[oid] = True
+            else:
+                rs[oid] = r[1]
+                print(oid, r[1])
+        return rs
     
     ''' 已验证 '''
     def 获取系统单项列表(self):
@@ -296,8 +327,6 @@ class 供应链api():
         msg = r.get('message') or str(r)
         return True if msg in self.成功的msg else msg
     
-
-    
     def 判断数据完整性(self, s):
         for i, x in enumerate(s.fillna('')):
             if type(x) is str:
@@ -345,6 +374,7 @@ class 供应链api():
         r = self.get('packages', params=data)['data']
         if 去除test:
             r = [x for x in r if not [y for y in ('test', '测试') if y in x['套餐名称'].lower()]]
+        self.转中文(r, {'package_presettle_price':'套餐预估结算价'})
         return r
 
     def 修改套餐(self, 套餐id, 套餐详情=None, **kvs):
